==> sms-service-1.8.0-sources.jar: org/opennms/sms/reflector/smsservice/MobileMsgResponse.java <==
/*
 * This file is part of the OpenNMS(R) Application.
 *
 * OpenNMS(R) is Copyright (C) 2009 The OpenNMS Group, Inc.  All rights reserved.
 * OpenNMS(R) is a derivative work, containing both original code, included code and modified
 * code that was published under the GNU General Public License. Copyrights for modified
 * and included code are below.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * For more information contact:
 * OpenNMS Licensing       <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 */
package org.opennms.sms.reflector.smsservice;

import org.opennms.protocols.rt.Response;

/**
 * SmsResponse
 *
 * @author brozow
 */
public abstract class MobileMsgResponse implements Response {
	private MobileMsgRequest m_request;
	private long m_receiveTime;

	public MobileMsgResponse(long receiveTime) {
		m_receiveTime = receiveTime;
	}

	public void setRequest(MobileMsgRequest req) {
		m_request = req;
	}

	public MobileMsgRequest getRequest() {
		return m_request;
	}

	public long getReceiveTime() {
		return m_receiveTime;
	}
	
    public abstract String getText();

}

==> sms-service-1.8.6-sources.jar: org/opennms/sms/reflector/smsservice/MobileMsgResponse.java <==
/*
 * This file is part of the OpenNMS(R) Application.
 *
 * OpenNMS(R) is Copyright (C) 2009 The OpenNMS Group, Inc.  All rights reserved.
 * OpenNMS(R) is a derivative work, containing both original code, included code and modified
 * code that was published under the GNU General Public License. Copyrights for modified
 * and included code are below.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * For more information contact:
 * OpenNMS Licensing       <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 */
package org.opennms.sms.reflector.smsservice;

import org.opennms.protocols.rt.Response;

/**
 * SmsResponse
 *
 * @author brozow
 * @version $Id: $
 */
public abstract class MobileMsgResponse implements Response {
	private MobileMsgRequest m_request;
	private long m_receiveTime;

	/**
	 * <p>Constructor for MobileMsgResponse.</p>
	 *
	 * @param receiveTime a long.
	 */
	public MobileMsgResponse(long receiveTime) {
		m_receiveTime = receiveTime;
	}

	/**
	 * <p>setRequest</p>
	 *
	 * @param req a {@link org.opennms.sms.reflector.smsservice.MobileMsgRequest} object.
	 */
	public void setRequest(MobileMsgRequest req) {
		m_request = req;
	}

	/**
	 * <p>getRequest</p>
	 *
	 * @return a {@link org.opennms.sms.reflector.smsservice.MobileMsgRequest} object.
	 */
	public MobileMsgRequest getRequest() {
		return m_request;
	}

	/**
	 * <p>getReceiveTime</p>
	 *
	 * @return a long.
	 */
	public long getReceiveTime() {
		return m_receiveTime;
	}
	
    /**
     * <p>getText</p>
     *
     * @return a {@link java.lang.String} object.
     */
    public abstract String getText();

}
